@@ -11,7 +11,7 @@ class Config:
         keys = 'keys'
         version = 'version'
         index = 'indexes'
-        update = 'updates'
+        task = 'tasks'
         stat = 'stats'
         search = 'search'
         document = 'documents'
@@ -25,6 +25,7 @@ class Config:
         accept_new_fields = 'accept-new-fields'
         filterable_attributes = 'filterable-attributes'
         sortable_attributes = 'sortable-attributes'
+        typo_tolerance = 'typo-tolerance'
         dumps = 'dumps'
 
     def __init__(
@@ -37,9 +38,9 @@ class Config:
         Parameters
         ----------
         url:
-            The url to the MeiliSearch API (ex: http://localhost:7700)
+            The url to the Meilisearch API (ex: http://localhost:7700)
         api_key:
-            The optional API key to access MeiliSearch
+            The optional API key to access Meilisearch
         """
 
         self.url = url
